Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - b -

- bernoulli_ccdf_log() : stan::math
- bernoulli_cdf() : stan::math
- bernoulli_cdf_log() : stan::math
- bernoulli_log() : stan::math
- bernoulli_logit_log() : stan::math
- bernoulli_rng() : stan::math
- bessel_first_kind() : stan::math
- bessel_second_kind() : stan::math
- beta_binomial_ccdf_log() : stan::math
- beta_binomial_cdf() : stan::math
- beta_binomial_cdf_log() : stan::math
- beta_binomial_log() : stan::math
- beta_binomial_rng() : stan::math
- beta_ccdf_log() : stan::math
- beta_cdf() : stan::math
- beta_cdf_log() : stan::math
- beta_log() : stan::math
- beta_rng() : stan::math
- binary_log_loss() : stan::math
- binomial_ccdf_log() : stan::math
- binomial_cdf() : stan::math
- binomial_cdf_log() : stan::math
- binomial_coefficient_log() : stan::math
- binomial_log() : stan::math
- binomial_logit_log() : stan::math
- binomial_rng() : stan::math
- block() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.